/* properties.c generated by valac 0.23.2.10-fed12, the Vala compiler
 * generated from properties.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <clutter/clutter.h>
#include <clutter-gtk/clutter-gtk.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <float.h>
#include <math.h>
#include <glib/gi18n-lib.h>
#include <libgd/gd.h>


#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;
typedef struct _BoxesPropertiesPrivate BoxesPropertiesPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _BoxesSidebarPrivate BoxesSidebarPrivate;

#define BOXES_TYPE_MINI_GRAPH (boxes_mini_graph_get_type ())
#define BOXES_MINI_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraph))
#define BOXES_MINI_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraphClass))
#define BOXES_IS_MINI_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MINI_GRAPH))
#define BOXES_IS_MINI_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MINI_GRAPH))
#define BOXES_MINI_GRAPH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraphClass))

typedef struct _BoxesMiniGraph BoxesMiniGraph;
typedef struct _BoxesMiniGraphClass BoxesMiniGraphClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;

#define BOXES_PROPERTIES_TYPE_PAGE_WIDGET (boxes_properties_page_widget_get_type ())
#define BOXES_PROPERTIES_PAGE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidget))
#define BOXES_PROPERTIES_PAGE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidgetClass))
#define BOXES_PROPERTIES_IS_PAGE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_PROPERTIES_TYPE_PAGE_WIDGET))
#define BOXES_PROPERTIES_IS_PAGE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_PROPERTIES_TYPE_PAGE_WIDGET))
#define BOXES_PROPERTIES_PAGE_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidgetClass))

typedef struct _BoxesPropertiesPageWidget BoxesPropertiesPageWidget;
typedef struct _BoxesPropertiesPageWidgetClass BoxesPropertiesPageWidgetClass;
typedef struct _Block47Data Block47Data;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))
typedef struct _BoxesPropertiesPageWidgetPrivate BoxesPropertiesPageWidgetPrivate;
typedef struct _Block48Data Block48Data;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
typedef struct _BoxesLibvirtMachinePrivate BoxesLibvirtMachinePrivate;
typedef struct _Block49Data Block49Data;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	ClutterActor* (*get_actor) (BoxesUI* self);
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesProperties {
	GtkNotebook parent_instance;
	BoxesPropertiesPrivate * priv;
};

struct _BoxesPropertiesClass {
	GtkNotebookClass parent_class;
};

struct _BoxesPropertiesPrivate {
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
	GtkClutterActor* gtk_actor;
	gulong stats_id;
	gboolean restore_fullscreen;
};

struct _BoxesApp {
	GObject parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	GObjectClass parent_class;
};

struct _BoxesSidebar {
	GtkNotebook parent_instance;
	BoxesSidebarPrivate * priv;
	GtkImage* screenshot;
	GtkListStore* props_listmodel;
	GtkTreeSelection* props_selection;
	GtkButton* shutdown_button;
	BoxesMiniGraph* cpu_graph;
	BoxesMiniGraph* io_graph;
	BoxesMiniGraph* net_graph;
};

struct _BoxesSidebarClass {
	GtkNotebookClass parent_class;
};

struct _Block47Data {
	int _ref_count_;
	BoxesProperties* self;
	BoxesPropertiesPageWidget* page;
};

struct _BoxesPropertiesPageWidget {
	GtkGrid parent_instance;
	BoxesPropertiesPageWidgetPrivate * priv;
	gboolean empty;
};

struct _BoxesPropertiesPageWidgetClass {
	GtkGridClass parent_class;
};

struct _Block48Data {
	int _ref_count_;
	BoxesProperties* self;
	BoxesLibvirtMachine* libvirt_machine;
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
	ClutterActor* (*get_item_actor) (BoxesCollectionItem* self);
};

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _BoxesLibvirtMachine {
	BoxesMachine parent_instance;
	BoxesLibvirtMachinePrivate * priv;
	gdouble* cpu_stats;
	gint cpu_stats_length1;
	gint _cpu_stats_size_;
	gdouble* io_stats;
	gint io_stats_length1;
	gint _io_stats_size_;
	gdouble* net_stats;
	gint net_stats_length1;
	gint _net_stats_size_;
};

struct _BoxesLibvirtMachineClass {
	BoxesMachineClass parent_class;
};

struct _Block49Data {
	int _ref_count_;
	BoxesProperties* self;
	BoxesMachine* machine;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

typedef void (*BoxesNotificationOKFunc) (void* user_data);
typedef void (*BoxesNotificationCancelFunc) (void* user_data);
struct _BoxesPropertiesPageWidgetPrivate {
	GList* properties;
};


static gpointer boxes_properties_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static gpointer boxes_properties_page_widget_parent_class = NULL;
static BoxesUIIface* boxes_properties_boxes_ui_parent_iface = NULL;

GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
#define BOXES_PROPERTIES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_PROPERTIES, BoxesPropertiesPrivate))
enum  {
	BOXES_PROPERTIES_DUMMY_PROPERTY,
	BOXES_PROPERTIES_ACTOR,
	BOXES_PROPERTIES_PREVIOUS_UI_STATE,
	BOXES_PROPERTIES_UI_STATE
};
BoxesProperties* boxes_properties_new (void);
BoxesProperties* boxes_properties_construct (GType object_type);
static void boxes_properties_ui_state_changed (BoxesProperties* self);
static void _boxes_properties_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_properties_setup_ui (BoxesProperties* self);
static void boxes_properties_list_append (BoxesProperties* self, GtkListStore* listmodel, const gchar* label, gboolean visible);
static void boxes_properties_populate (BoxesProperties* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GType boxes_mini_graph_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
gboolean boxes_machine_is_running (BoxesMachine* self);
static GType boxes_properties_page_widget_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static Block47Data* block47_data_ref (Block47Data* _data47_);
static void block47_data_unref (void * _userdata_);
static BoxesPropertiesPageWidget* boxes_properties_page_widget_new (BoxesPropertiesPage page, BoxesMachine* machine);
static BoxesPropertiesPageWidget* boxes_properties_page_widget_construct (GType object_type, BoxesPropertiesPage page, BoxesMachine* machine);
static void _____lambda55_ (Block47Data* _data47_);
static void ______lambda55__boxes_properties_page_widget_refresh_properties (BoxesPropertiesPageWidget* _sender, gpointer self);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
gboolean boxes_app_get_fullscreen (BoxesApp* self);
void boxes_app_set_fullscreen (BoxesApp* self, gboolean value);
static Block48Data* block48_data_ref (Block48Data* _data48_);
static void block48_data_unref (void * _userdata_);
static void ____lambda53_ (Block48Data* _data48_);
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
void boxes_mini_graph_set_points (BoxesMiniGraph* self, gdouble* value, int value_length1);
static void _____lambda53__boxes_libvirt_machine_stats_updated (BoxesLibvirtMachine* _sender, gpointer self);
static Block49Data* block49_data_ref (Block49Data* _data49_);
static void block49_data_unref (void * _userdata_);
static gboolean boxes_properties_page_widget_flush_changes (BoxesPropertiesPageWidget* self);
gboolean boxes_machine_is_on (BoxesMachine* self);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
GdNotification* boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationCancelFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify, gint timeout);
static void _____lambda56_ (Block49Data* _data49_);
void boxes_machine_restart (BoxesMachine* self);
static void ______lambda56__boxes_notification_ok_func (gpointer self);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
void boxes_fade_actor (ClutterActor* actor, guint opacity);
ClutterActor* boxes_ui_get_actor (BoxesUI* self);
#define BOXES_PROPERTIES_PAGE_WIDGET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidgetPrivate))
enum  {
	BOXES_PROPERTIES_PAGE_WIDGET_DUMMY_PROPERTY
};
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
GList* boxes_machine_get_properties (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
const gchar* boxes_property_get_description (BoxesProperty* self);
GtkWidget* boxes_property_get_widget (BoxesProperty* self);
GtkWidget* boxes_property_get_extra_widget (BoxesProperty* self);
static void _____lambda54_ (BoxesPropertiesPageWidget* self);
static void ______lambda54__boxes_property_refresh_properties (BoxesProperty* _sender, gpointer self);
void boxes_property_flush (BoxesProperty* self);
gboolean boxes_property_get_reboot_required (BoxesProperty* self);
static void boxes_properties_page_widget_finalize (GObject* obj);
static void boxes_properties_finalize (GObject* obj);
static void _vala_boxes_properties_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_properties_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


GType boxes_properties_page_get_type (void) {
	static volatile gsize boxes_properties_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_PROPERTIES_PAGE_LOGIN, "BOXES_PROPERTIES_PAGE_LOGIN", "login"}, {BOXES_PROPERTIES_PAGE_SYSTEM, "BOXES_PROPERTIES_PAGE_SYSTEM", "system"}, {BOXES_PROPERTIES_PAGE_DISPLAY, "BOXES_PROPERTIES_PAGE_DISPLAY", "display"}, {BOXES_PROPERTIES_PAGE_DEVICES, "BOXES_PROPERTIES_PAGE_DEVICES", "devices"}, {BOXES_PROPERTIES_PAGE_LAST, "BOXES_PROPERTIES_PAGE_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_properties_page_type_id;
		boxes_properties_page_type_id = g_enum_register_static ("BoxesPropertiesPage", values);
		g_once_init_leave (&boxes_properties_page_type_id__volatile, boxes_properties_page_type_id);
	}
	return boxes_properties_page_type_id__volatile;
}


static void _boxes_properties_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_ui_state_changed ((BoxesProperties*) self);
#line 590 "properties.c"
}


BoxesProperties* boxes_properties_construct (GType object_type) {
	BoxesProperties * self = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) g_object_new (object_type, NULL);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_signal_connect_object ((GObject*) self, "notify::ui-state", (GCallback) _boxes_properties_ui_state_changed_g_object_notify, self, 0);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_setup_ui (self);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return self;
#line 604 "properties.c"
}


BoxesProperties* boxes_properties_new (void) {
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return boxes_properties_construct (BOXES_TYPE_PROPERTIES);
#line 611 "properties.c"
}


static void boxes_properties_list_append (BoxesProperties* self, GtkListStore* listmodel, const gchar* label, gboolean visible) {
	GtkTreeIter iter = {0};
	GtkListStore* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	GtkListStore* _tmp2_ = NULL;
	GtkTreeIter _tmp3_ = {0};
	const gchar* _tmp4_ = NULL;
	GtkListStore* _tmp5_ = NULL;
	GtkTreeIter _tmp6_ = {0};
	gboolean _tmp7_ = FALSE;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (listmodel != NULL);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (label != NULL);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = listmodel;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_list_store_append (_tmp0_, &_tmp1_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	iter = _tmp1_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = listmodel;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = iter;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4_ = label;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_list_store_set (_tmp2_, &_tmp3_, 0, _tmp4_, -1);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = listmodel;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = iter;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp7_ = visible;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_list_store_set (_tmp5_, &_tmp6_, 1, _tmp7_, -1);
#line 653 "properties.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return self ? g_object_ref (self) : NULL;
#line 660 "properties.c"
}


static Block47Data* block47_data_ref (Block47Data* _data47_) {
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_atomic_int_inc (&_data47_->_ref_count_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return _data47_;
#line 669 "properties.c"
}


static void block47_data_unref (void * _userdata_) {
	Block47Data* _data47_;
	_data47_ = (Block47Data*) _userdata_;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (g_atomic_int_dec_and_test (&_data47_->_ref_count_)) {
#line 678 "properties.c"
		BoxesProperties* self;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		self = _data47_->self;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (_data47_->page);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (self);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_slice_free (Block47Data, _data47_);
#line 688 "properties.c"
	}
}


static void _____lambda55_ (Block47Data* _data47_) {
	BoxesProperties* self;
	BoxesPropertiesPageWidget* current_page = NULL;
	BoxesPropertiesPageWidget* _tmp0_ = NULL;
	BoxesPropertiesPageWidget* _tmp1_ = NULL;
	GtkTreePath* path = NULL;
	GtkTreePath* _tmp2_ = NULL;
	BoxesApp* _tmp3_ = NULL;
	BoxesSidebar* _tmp4_ = NULL;
	GtkTreeSelection* _tmp5_ = NULL;
	BoxesPropertiesPageWidget* _tmp6_ = NULL;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = _data47_->self;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = _data47_->page;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	current_page = _tmp1_;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_populate (self);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = gtk_tree_path_new_from_indices (current_page, -1);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	path = _tmp2_;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = boxes_app_app;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4_ = _tmp3_->sidebar;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = _tmp4_->props_selection;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_tree_selection_select_path (_tmp5_, path);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = _g_object_ref0 (current_page);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (_data47_->page);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_data47_->page = _tmp6_;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_gtk_tree_path_free0 (path);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (current_page);
#line 736 "properties.c"
}


static void ______lambda55__boxes_properties_page_widget_refresh_properties (BoxesPropertiesPageWidget* _sender, gpointer self) {
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_____lambda55_ (self);
#line 743 "properties.c"
}


static void boxes_properties_populate (BoxesProperties* self) {
	BoxesApp* _tmp0_ = NULL;
	BoxesSidebar* _tmp1_ = NULL;
	GtkListStore* _tmp2_ = NULL;
	BoxesMachine* machine = NULL;
	BoxesApp* _tmp6_ = NULL;
	BoxesCollectionItem* _tmp7_ = NULL;
	BoxesMachine* _tmp8_ = NULL;
	BoxesLibvirtMachine* libvirt_machine = NULL;
	BoxesApp* _tmp9_ = NULL;
	BoxesCollectionItem* _tmp10_ = NULL;
	BoxesLibvirtMachine* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	BoxesLibvirtMachine* _tmp13_ = NULL;
	BoxesApp* _tmp16_ = NULL;
	BoxesSidebar* _tmp17_ = NULL;
	GtkButton* _tmp18_ = NULL;
	BoxesMachine* _tmp19_ = NULL;
	BoxesPropertiesPage current_page = 0;
	BoxesLibvirtMachine* _tmp43_ = NULL;
	GtkTreePath* path = NULL;
	BoxesPropertiesPage _tmp47_ = 0;
	GtkTreePath* _tmp48_ = NULL;
	BoxesApp* _tmp49_ = NULL;
	BoxesSidebar* _tmp50_ = NULL;
	GtkTreeSelection* _tmp51_ = NULL;
	GtkTreePath* _tmp52_ = NULL;
	BoxesPropertiesPage _tmp53_ = 0;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = boxes_app_app;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp1_ = _tmp0_->sidebar;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = _tmp1_->props_listmodel;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_list_store_clear (_tmp2_);
#line 785 "properties.c"
	{
		gint i = 0;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		i = 0;
#line 790 "properties.c"
		{
			gboolean _tmp3_ = FALSE;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp3_ = TRUE;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			while (TRUE) {
#line 797 "properties.c"
				gint _tmp5_ = 0;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				if (!_tmp3_) {
#line 801 "properties.c"
					gint _tmp4_ = 0;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp4_ = i;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					i = _tmp4_ + 1;
#line 807 "properties.c"
				}
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp3_ = FALSE;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp5_ = i;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				if (!(_tmp5_ < ((gint) BOXES_PROPERTIES_PAGE_LAST))) {
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					break;
#line 817 "properties.c"
				}
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				gtk_notebook_remove_page ((GtkNotebook*) self, -1);
#line 821 "properties.c"
			}
		}
	}
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = boxes_app_app;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp7_ = _tmp6_->current_item;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp7_) : NULL);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	machine = _tmp8_;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp9_ = boxes_app_app;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp10_ = _tmp9_->current_item;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp10_) : NULL);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	libvirt_machine = _tmp11_;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp13_ = libvirt_machine;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp13_ != NULL) {
#line 845 "properties.c"
		BoxesLibvirtMachine* _tmp14_ = NULL;
		gboolean _tmp15_ = FALSE;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp14_ = libvirt_machine;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp15_ = boxes_machine_is_running ((BoxesMachine*) _tmp14_);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp12_ = _tmp15_;
#line 854 "properties.c"
	} else {
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp12_ = FALSE;
#line 858 "properties.c"
	}
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp16_ = boxes_app_app;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp17_ = _tmp16_->sidebar;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp18_ = _tmp17_->shutdown_button;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp18_, _tmp12_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp19_ = machine;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp19_ == NULL) {
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (libvirt_machine);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (machine);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		return;
#line 878 "properties.c"
	}
	{
		gint i = 0;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		i = 0;
#line 884 "properties.c"
		{
			gboolean _tmp20_ = FALSE;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp20_ = TRUE;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			while (TRUE) {
#line 891 "properties.c"
				Block47Data* _data47_;
				gint _tmp22_ = 0;
				gint _tmp23_ = 0;
				BoxesMachine* _tmp24_ = NULL;
				BoxesPropertiesPageWidget* _tmp25_ = NULL;
				BoxesPropertiesPageWidget* _tmp26_ = NULL;
				gint _tmp27_ = 0;
				gchar* _tmp28_ = NULL;
				gchar* _tmp29_ = NULL;
				gchar* _tmp30_ = NULL;
				gchar* _tmp31_ = NULL;
				BoxesPropertiesPageWidget* _tmp32_ = NULL;
				BoxesPropertiesPageWidget* _tmp33_ = NULL;
				BoxesPropertiesPageWidget* _tmp34_ = NULL;
				BoxesApp* _tmp35_ = NULL;
				BoxesSidebar* _tmp36_ = NULL;
				GtkListStore* _tmp37_ = NULL;
				BoxesPropertiesPageWidget* _tmp38_ = NULL;
				const gchar* _tmp39_ = NULL;
				const gchar* _tmp40_ = NULL;
				BoxesPropertiesPageWidget* _tmp41_ = NULL;
				gboolean _tmp42_ = FALSE;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_data47_ = g_slice_new0 (Block47Data);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_data47_->_ref_count_ = 1;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_data47_->self = g_object_ref (self);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				if (!_tmp20_) {
#line 922 "properties.c"
					gint _tmp21_ = 0;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp21_ = i;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					i = _tmp21_ + 1;
#line 928 "properties.c"
				}
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp20_ = FALSE;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp22_ = i;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				if (!(_tmp22_ < ((gint) BOXES_PROPERTIES_PAGE_LAST))) {
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					block47_data_unref (_data47_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_data47_ = NULL;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					break;
#line 942 "properties.c"
				}
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp23_ = i;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp24_ = machine;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp25_ = boxes_properties_page_widget_new (_tmp23_, _tmp24_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				g_object_ref_sink (_tmp25_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_data47_->page = _tmp25_;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp26_ = _data47_->page;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				gtk_notebook_append_page ((GtkNotebook*) self, (GtkWidget*) _tmp26_, NULL);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp27_ = i;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp28_ = g_strdup_printf ("%i", _tmp27_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp29_ = _tmp28_;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp30_ = g_strconcat ("boxes-property-", _tmp29_, NULL);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp31_ = _tmp30_;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp32_ = _data47_->page;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp33_ = _g_object_ref0 (_tmp32_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				g_object_set_data_full ((GObject*) self, _tmp31_, _tmp33_, g_object_unref);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_free0 (_tmp31_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_free0 (_tmp29_);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp34_ = _data47_->page;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				g_signal_connect_data (_tmp34_, "refresh-properties", (GCallback) ______lambda55__boxes_properties_page_widget_refresh_properties, block47_data_ref (_data47_), (GClosureNotify) block47_data_unref, 0);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp35_ = boxes_app_app;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp36_ = _tmp35_->sidebar;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp37_ = _tmp36_->props_listmodel;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp38_ = _data47_->page;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp39_ = gtk_widget_get_name ((GtkWidget*) _tmp38_);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp40_ = _tmp39_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp41_ = _data47_->page;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp42_ = _tmp41_->empty;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				boxes_properties_list_append (self, _tmp37_, _tmp40_, !_tmp42_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				block47_data_unref (_data47_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_data47_ = NULL;
#line 1004 "properties.c"
			}
		}
	}
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp43_ = libvirt_machine;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp43_ != NULL) {
#line 1012 "properties.c"
		BoxesPropertiesPage _tmp44_ = 0;
		BoxesUIState _tmp45_ = 0;
		BoxesUIState _tmp46_ = 0;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp45_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp46_ = _tmp45_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		if (_tmp46_ == BOXES_UI_STATE_WIZARD) {
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp44_ = BOXES_PROPERTIES_PAGE_SYSTEM;
#line 1024 "properties.c"
		} else {
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp44_ = BOXES_PROPERTIES_PAGE_LOGIN;
#line 1028 "properties.c"
		}
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		current_page = _tmp44_;
#line 1032 "properties.c"
	} else {
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		current_page = BOXES_PROPERTIES_PAGE_LOGIN;
#line 1036 "properties.c"
	}
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp47_ = current_page;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp48_ = gtk_tree_path_new_from_indices (_tmp47_, -1);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	path = _tmp48_;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp49_ = boxes_app_app;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp50_ = _tmp49_->sidebar;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp51_ = _tmp50_->props_selection;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp52_ = path;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_tree_selection_select_path (_tmp51_, _tmp52_);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp53_ = current_page;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_notebook_set_current_page ((GtkNotebook*) self, (gint) _tmp53_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_gtk_tree_path_free0 (path);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (libvirt_machine);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (machine);
#line 1064 "properties.c"
}


static void boxes_properties_setup_ui (BoxesProperties* self) {
	GtkStyleContext* _tmp0_ = NULL;
	GtkClutterActor* _tmp1_ = NULL;
	GtkClutterActor* _tmp2_ = NULL;
	GtkWidget* _tmp3_ = NULL;
	GtkStyleContext* _tmp4_ = NULL;
	GtkClutterActor* _tmp5_ = NULL;
	GtkClutterActor* _tmp6_ = NULL;
	GtkClutterActor* _tmp7_ = NULL;
	GtkClutterActor* _tmp8_ = NULL;
	GtkClutterActor* _tmp9_ = NULL;
	GtkClutterActor* _tmp10_ = NULL;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_notebook_set_show_tabs ((GtkNotebook*) self, FALSE);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_style_context_add_class (_tmp0_, "boxes-bg");
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp1_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents ((GtkWidget*) self);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp1_);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->gtk_actor = _tmp1_;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = self->priv->gtk_actor;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = gtk_clutter_actor_get_widget (_tmp2_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4_ = gtk_widget_get_style_context (_tmp3_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_style_context_add_class (_tmp4_, "boxes-bg");
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = self->priv->gtk_actor;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp5_, "properties");
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = self->priv->gtk_actor;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	clutter_actor_set_opacity ((ClutterActor*) _tmp6_, (guint) 0);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp7_ = self->priv->gtk_actor;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	clutter_actor_set_x_align ((ClutterActor*) _tmp7_, CLUTTER_ACTOR_ALIGN_FILL);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp8_ = self->priv->gtk_actor;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	clutter_actor_set_y_align ((ClutterActor*) _tmp8_, CLUTTER_ACTOR_ALIGN_FILL);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp9_ = self->priv->gtk_actor;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	clutter_actor_set_x_expand ((ClutterActor*) _tmp9_, TRUE);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp10_ = self->priv->gtk_actor;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	clutter_actor_set_y_expand ((ClutterActor*) _tmp10_, TRUE);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 1130 "properties.c"
}


static Block48Data* block48_data_ref (Block48Data* _data48_) {
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_atomic_int_inc (&_data48_->_ref_count_);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return _data48_;
#line 1139 "properties.c"
}


static void block48_data_unref (void * _userdata_) {
	Block48Data* _data48_;
	_data48_ = (Block48Data*) _userdata_;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (g_atomic_int_dec_and_test (&_data48_->_ref_count_)) {
#line 1148 "properties.c"
		BoxesProperties* self;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		self = _data48_->self;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (_data48_->libvirt_machine);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (self);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_slice_free (Block48Data, _data48_);
#line 1158 "properties.c"
	}
}


static void ____lambda53_ (Block48Data* _data48_) {
	BoxesProperties* self;
	BoxesApp* _tmp0_ = NULL;
	BoxesSidebar* _tmp1_ = NULL;
	BoxesMiniGraph* _tmp2_ = NULL;
	BoxesLibvirtMachine* _tmp3_ = NULL;
	gdouble* _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	BoxesApp* _tmp5_ = NULL;
	BoxesSidebar* _tmp6_ = NULL;
	BoxesMiniGraph* _tmp7_ = NULL;
	BoxesLibvirtMachine* _tmp8_ = NULL;
	gdouble* _tmp9_ = NULL;
	gint _tmp9__length1 = 0;
	BoxesApp* _tmp10_ = NULL;
	BoxesSidebar* _tmp11_ = NULL;
	BoxesMiniGraph* _tmp12_ = NULL;
	BoxesLibvirtMachine* _tmp13_ = NULL;
	gdouble* _tmp14_ = NULL;
	gint _tmp14__length1 = 0;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = _data48_->self;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = boxes_app_app;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp1_ = _tmp0_->sidebar;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = _tmp1_->cpu_graph;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = _data48_->libvirt_machine;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4_ = _tmp3_->cpu_stats;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4__length1 = _tmp3_->cpu_stats_length1;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_mini_graph_set_points (_tmp2_, _tmp4_, _tmp4__length1);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = boxes_app_app;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = _tmp5_->sidebar;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp7_ = _tmp6_->net_graph;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp8_ = _data48_->libvirt_machine;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp9_ = _tmp8_->net_stats;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp9__length1 = _tmp8_->net_stats_length1;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_mini_graph_set_points (_tmp7_, _tmp9_, _tmp9__length1);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp10_ = boxes_app_app;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp11_ = _tmp10_->sidebar;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp12_ = _tmp11_->io_graph;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp13_ = _data48_->libvirt_machine;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp14_ = _tmp13_->io_stats;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp14__length1 = _tmp13_->io_stats_length1;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_mini_graph_set_points (_tmp12_, _tmp14_, _tmp14__length1);
#line 1227 "properties.c"
}


static void _____lambda53__boxes_libvirt_machine_stats_updated (BoxesLibvirtMachine* _sender, gpointer self) {
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	____lambda53_ (self);
#line 1234 "properties.c"
}


static Block49Data* block49_data_ref (Block49Data* _data49_) {
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_atomic_int_inc (&_data49_->_ref_count_);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return _data49_;
#line 1243 "properties.c"
}


static void block49_data_unref (void * _userdata_) {
	Block49Data* _data49_;
	_data49_ = (Block49Data*) _userdata_;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (g_atomic_int_dec_and_test (&_data49_->_ref_count_)) {
#line 1252 "properties.c"
		BoxesProperties* self;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		self = _data49_->self;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (_data49_->machine);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (self);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_slice_free (Block49Data, _data49_);
#line 1262 "properties.c"
	}
}


static void _____lambda56_ (Block49Data* _data49_) {
	BoxesProperties* self;
	BoxesMachine* _tmp0_ = NULL;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = _data49_->self;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = _data49_->machine;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_machine_restart (_tmp0_);
#line 1276 "properties.c"
}


static void ______lambda56__boxes_notification_ok_func (gpointer self) {
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_____lambda56_ (self);
#line 1283 "properties.c"
}


static void boxes_properties_ui_state_changed (BoxesProperties* self) {
	gulong _tmp0_ = 0UL;
	BoxesUIState _tmp4_ = 0;
	BoxesUIState _tmp5_ = 0;
	gint _tmp60_ = 0;
	BoxesUIState _tmp61_ = 0;
	BoxesUIState _tmp62_ = 0;
	ClutterActor* _tmp63_ = NULL;
	ClutterActor* _tmp64_ = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->stats_id;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp0_ != ((gulong) 0)) {
#line 1302 "properties.c"
		BoxesApp* _tmp1_ = NULL;
		BoxesCollectionItem* _tmp2_ = NULL;
		gulong _tmp3_ = 0UL;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp1_ = boxes_app_app;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp2_ = _tmp1_->current_item;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp3_ = self->priv->stats_id;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_signal_handler_disconnect ((GObject*) _tmp2_, _tmp3_);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		self->priv->stats_id = (gulong) 0;
#line 1316 "properties.c"
	}
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = _tmp4_;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp5_ == BOXES_UI_STATE_PROPERTIES) {
#line 1324 "properties.c"
		gboolean _tmp6_ = FALSE;
		BoxesUIState _tmp7_ = 0;
		BoxesUIState _tmp8_ = 0;
		BoxesApp* _tmp12_ = NULL;
		BoxesApp* _tmp13_ = NULL;
		BoxesCollectionItem* _tmp14_ = NULL;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp7_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp8_ = _tmp7_;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		if (_tmp8_ == BOXES_UI_STATE_DISPLAY) {
#line 1337 "properties.c"
			BoxesApp* _tmp9_ = NULL;
			gboolean _tmp10_ = FALSE;
			gboolean _tmp11_ = FALSE;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp9_ = boxes_app_app;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp10_ = boxes_app_get_fullscreen (_tmp9_);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp11_ = _tmp10_;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp6_ = _tmp11_;
#line 1349 "properties.c"
		} else {
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp6_ = FALSE;
#line 1353 "properties.c"
		}
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		self->priv->restore_fullscreen = _tmp6_;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp12_ = boxes_app_app;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_app_set_fullscreen (_tmp12_, FALSE);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp13_ = boxes_app_app;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp14_ = _tmp13_->current_item;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, BOXES_TYPE_LIBVIRT_MACHINE)) {
#line 1367 "properties.c"
			Block48Data* _data48_;
			BoxesApp* _tmp15_ = NULL;
			BoxesCollectionItem* _tmp16_ = NULL;
			BoxesLibvirtMachine* _tmp17_ = NULL;
			BoxesLibvirtMachine* _tmp18_ = NULL;
			gulong _tmp19_ = 0UL;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data48_ = g_slice_new0 (Block48Data);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data48_->_ref_count_ = 1;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data48_->self = g_object_ref (self);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp15_ = boxes_app_app;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp16_ = _tmp15_->current_item;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp17_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp16_) : NULL);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data48_->libvirt_machine = _tmp17_;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp18_ = _data48_->libvirt_machine;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp19_ = g_signal_connect_data (_tmp18_, "stats-updated", (GCallback) _____lambda53__boxes_libvirt_machine_stats_updated, block48_data_ref (_data48_), (GClosureNotify) block48_data_unref, 0);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			self->priv->stats_id = _tmp19_;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			block48_data_unref (_data48_);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data48_ = NULL;
#line 1398 "properties.c"
		}
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_properties_populate (self);
#line 1402 "properties.c"
	} else {
		BoxesUIState _tmp20_ = 0;
		BoxesUIState _tmp21_ = 0;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp20_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp21_ = _tmp20_;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		if (_tmp21_ == BOXES_UI_STATE_PROPERTIES) {
#line 1412 "properties.c"
			Block49Data* _data49_;
			gboolean reboot_required = FALSE;
			BoxesApp* _tmp36_ = NULL;
			BoxesCollectionItem* _tmp37_ = NULL;
			BoxesMachine* _tmp38_ = NULL;
			gboolean _tmp39_ = FALSE;
			gboolean _tmp40_ = FALSE;
			gboolean _tmp58_ = FALSE;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data49_ = g_slice_new0 (Block49Data);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data49_->_ref_count_ = 1;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data49_->self = g_object_ref (self);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			reboot_required = FALSE;
#line 1429 "properties.c"
			{
				gint i = 0;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				i = 0;
#line 1434 "properties.c"
				{
					gboolean _tmp22_ = FALSE;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp22_ = TRUE;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					while (TRUE) {
#line 1441 "properties.c"
						gint _tmp24_ = 0;
						BoxesPropertiesPageWidget* page = NULL;
						gint _tmp25_ = 0;
						gchar* _tmp26_ = NULL;
						gchar* _tmp27_ = NULL;
						gchar* _tmp28_ = NULL;
						gchar* _tmp29_ = NULL;
						gconstpointer _tmp30_ = NULL;
						BoxesPropertiesPageWidget* _tmp31_ = NULL;
						BoxesPropertiesPageWidget* _tmp32_ = NULL;
						gboolean _tmp33_ = FALSE;
						BoxesPropertiesPageWidget* _tmp34_ = NULL;
						gboolean _tmp35_ = FALSE;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						if (!_tmp22_) {
#line 1457 "properties.c"
							gint _tmp23_ = 0;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
							_tmp23_ = i;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
							i = _tmp23_ + 1;
#line 1463 "properties.c"
						}
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp22_ = FALSE;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp24_ = i;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						if (!(_tmp24_ < ((gint) BOXES_PROPERTIES_PAGE_LAST))) {
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
							break;
#line 1473 "properties.c"
						}
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp25_ = i;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp26_ = g_strdup_printf ("%i", _tmp25_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp27_ = _tmp26_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp28_ = g_strconcat ("boxes-property-", _tmp27_, NULL);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp29_ = _tmp28_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp30_ = g_object_get_data ((GObject*) self, _tmp29_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp31_ = _g_object_ref0 ((BoxesPropertiesPageWidget*) _tmp30_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp32_ = _tmp31_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_free0 (_tmp29_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_free0 (_tmp27_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						page = _tmp32_;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp33_ = reboot_required;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp34_ = page;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp35_ = boxes_properties_page_widget_flush_changes (_tmp34_);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						reboot_required = _tmp33_ | _tmp35_;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_object_unref0 (page);
#line 1507 "properties.c"
					}
				}
			}
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp36_ = boxes_app_app;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp37_ = _tmp36_->current_item;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp38_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp37_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp37_) : NULL);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data49_->machine = _tmp38_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp40_ = reboot_required;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			if (_tmp40_) {
#line 1523 "properties.c"
				gboolean _tmp41_ = FALSE;
				BoxesMachine* _tmp42_ = NULL;
				gboolean _tmp43_ = FALSE;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp42_ = _data49_->machine;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp43_ = boxes_machine_is_on (_tmp42_);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				if (_tmp43_) {
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp41_ = TRUE;
#line 1535 "properties.c"
				} else {
					BoxesMachine* _tmp44_ = NULL;
					BoxesMachineMachineState _tmp45_ = 0;
					BoxesMachineMachineState _tmp46_ = 0;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp44_ = _data49_->machine;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp45_ = boxes_machine_get_state (_tmp44_);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp46_ = _tmp45_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp41_ = _tmp46_ == BOXES_MACHINE_MACHINE_STATE_SAVED;
#line 1548 "properties.c"
				}
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp39_ = _tmp41_;
#line 1552 "properties.c"
			} else {
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp39_ = FALSE;
#line 1556 "properties.c"
			}
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			if (_tmp39_) {
#line 1560 "properties.c"
				gchar* message = NULL;
				const gchar* _tmp47_ = NULL;
				BoxesMachine* _tmp48_ = NULL;
				const gchar* _tmp49_ = NULL;
				const gchar* _tmp50_ = NULL;
				gchar* _tmp51_ = NULL;
				BoxesApp* _tmp52_ = NULL;
				BoxesNotificationbar* _tmp53_ = NULL;
				const gchar* _tmp54_ = NULL;
				const gchar* _tmp55_ = NULL;
				GdNotification* _tmp56_ = NULL;
				GdNotification* _tmp57_ = NULL;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp47_ = _ ("Changes require restart of '%s'.");
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp48_ = _data49_->machine;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp49_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp48_);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp50_ = _tmp49_;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp51_ = g_strdup_printf (_tmp47_, _tmp50_);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				message = _tmp51_;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp52_ = boxes_app_app;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp53_ = _tmp52_->notificationbar;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp54_ = message;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp55_ = _ ("_Restart");
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp56_ = boxes_notificationbar_display_for_action (_tmp53_, _tmp54_, _tmp55_, ______lambda56__boxes_notification_ok_func, block49_data_ref (_data49_), block49_data_unref, NULL, NULL, NULL, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp57_ = _tmp56_;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_object_unref0 (_tmp57_);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_free0 (message);
#line 1601 "properties.c"
			}
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp58_ = self->priv->restore_fullscreen;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			if (_tmp58_) {
#line 1607 "properties.c"
				BoxesApp* _tmp59_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp59_ = boxes_app_app;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				boxes_app_set_fullscreen (_tmp59_, TRUE);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				self->priv->restore_fullscreen = FALSE;
#line 1615 "properties.c"
			}
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			block49_data_unref (_data49_);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data49_ = NULL;
#line 1621 "properties.c"
		}
	}
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp61_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp62_ = _tmp61_;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp62_ == BOXES_UI_STATE_PROPERTIES) {
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp60_ = 255;
#line 1632 "properties.c"
	} else {
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp60_ = 0;
#line 1636 "properties.c"
	}
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp63_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp64_ = _tmp63_;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_fade_actor (_tmp64_, (guint) _tmp60_);
#line 1644 "properties.c"
}


static ClutterActor* boxes_properties_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesProperties* self;
	GtkClutterActor* _tmp0_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) base;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->gtk_actor;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	result = (ClutterActor*) _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return result;
#line 1660 "properties.c"
}


static BoxesUIState boxes_properties_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesProperties* self;
	BoxesUIState _tmp0_ = 0;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) base;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	result = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return result;
#line 1676 "properties.c"
}


static void boxes_properties_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesProperties* self;
	BoxesUIState _tmp0_ = 0;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) base;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = value;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->_previous_ui_state = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_notify ((GObject *) self, "previous-ui-state");
#line 1691 "properties.c"
}


static BoxesUIState boxes_properties_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesProperties* self;
	BoxesUIState _tmp0_ = 0;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) base;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->_ui_state;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	result = _tmp0_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return result;
#line 1707 "properties.c"
}


static void boxes_properties_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesProperties* self;
	BoxesUIState _tmp0_ = 0;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) base;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = value;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->_ui_state = _tmp0_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_notify ((GObject *) self, "ui-state");
#line 1722 "properties.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1729 "properties.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_list_free (self);
#line 1738 "properties.c"
}


static void _____lambda54_ (BoxesPropertiesPageWidget* self) {
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_signal_emit_by_name (self, "refresh-properties");
#line 1745 "properties.c"
}


static void ______lambda54__boxes_property_refresh_properties (BoxesProperty* _sender, gpointer self) {
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_____lambda54_ ((BoxesPropertiesPageWidget*) self);
#line 1752 "properties.c"
}


static BoxesPropertiesPageWidget* boxes_properties_page_widget_construct (GType object_type, BoxesPropertiesPage page, BoxesMachine* machine) {
	BoxesPropertiesPageWidget * self = NULL;
	BoxesPropertiesPage _tmp0_ = 0;
	PropertyCreationFlag flags = 0;
	BoxesMachine* _tmp5_ = NULL;
	BoxesPropertiesPage _tmp6_ = 0;
	GList* _tmp7_ = NULL;
	GList* _tmp8_ = NULL;
	guint _tmp9_ = 0U;
	gboolean _tmp10_ = FALSE;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesPropertiesPageWidget*) g_object_new (object_type, NULL);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = page;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	switch (_tmp0_) {
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PAGE_LOGIN:
#line 1776 "properties.c"
		{
			const gchar* _tmp1_ = NULL;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp1_ = _ ("Login");
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			gtk_widget_set_name ((GtkWidget*) self, _tmp1_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			break;
#line 1785 "properties.c"
		}
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PAGE_SYSTEM:
#line 1789 "properties.c"
		{
			const gchar* _tmp2_ = NULL;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp2_ = _ ("System");
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			gtk_widget_set_name ((GtkWidget*) self, _tmp2_);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			break;
#line 1798 "properties.c"
		}
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PAGE_DISPLAY:
#line 1802 "properties.c"
		{
			const gchar* _tmp3_ = NULL;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp3_ = _ ("Display");
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			gtk_widget_set_name ((GtkWidget*) self, _tmp3_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			break;
#line 1811 "properties.c"
		}
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PAGE_DEVICES:
#line 1815 "properties.c"
		{
			const gchar* _tmp4_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp4_ = _ ("Devices");
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			gtk_widget_set_name ((GtkWidget*) self, _tmp4_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			break;
#line 1824 "properties.c"
		}
		default:
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 1829 "properties.c"
	}
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_set ((GtkWidget*) self, "margin", 20, NULL);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_set_row_spacing ((GtkGrid*) self, 10);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_set_column_spacing ((GtkGrid*) self, 20);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_valign ((GtkWidget*) self, GTK_ALIGN_START);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	flags = PROPERTY_CREATION_FLAG_NONE;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = machine;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = page;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp7_ = boxes_machine_get_properties (_tmp5_, _tmp6_, &flags);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	__g_list_free__g_object_unref0_0 (self->priv->properties);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->properties = _tmp7_;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp8_ = self->priv->properties;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp9_ = g_list_length (_tmp8_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->empty = _tmp9_ == ((guint) 0);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp10_ = self->empty;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (!_tmp10_) {
#line 1861 "properties.c"
		gint current_row = 0;
		GList* _tmp11_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		current_row = 1;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp11_ = self->priv->properties;
#line 1868 "properties.c"
		{
			GList* property_collection = NULL;
			GList* property_it = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			property_collection = _tmp11_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			for (property_it = property_collection; property_it != NULL; property_it = property_it->next) {
#line 1876 "properties.c"
				BoxesProperty* _tmp12_ = NULL;
				BoxesProperty* property = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp12_ = _g_object_ref0 ((BoxesProperty*) property_it->data);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				property = _tmp12_;
#line 1883 "properties.c"
				{
					BoxesProperty* _tmp13_ = NULL;
					const gchar* _tmp14_ = NULL;
					const gchar* _tmp15_ = NULL;
					GtkWidget* widget = NULL;
					BoxesProperty* _tmp42_ = NULL;
					GtkWidget* _tmp43_ = NULL;
					GtkWidget* _tmp44_ = NULL;
					GtkWidget* _tmp45_ = NULL;
					GtkWidget* _tmp46_ = NULL;
					BoxesProperty* _tmp52_ = NULL;
					gint _tmp53_ = 0;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp13_ = property;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp14_ = boxes_property_get_description (_tmp13_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp15_ = _tmp14_;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					if (_tmp15_ != NULL) {
#line 1904 "properties.c"
						GtkLabel* label_name = NULL;
						BoxesProperty* _tmp16_ = NULL;
						const gchar* _tmp17_ = NULL;
						const gchar* _tmp18_ = NULL;
						GtkLabel* _tmp19_ = NULL;
						GtkLabel* _tmp20_ = NULL;
						GtkStyleContext* _tmp21_ = NULL;
						GtkLabel* _tmp22_ = NULL;
						GtkLabel* _tmp23_ = NULL;
						GtkLabel* _tmp24_ = NULL;
						GtkLabel* _tmp25_ = NULL;
						gint _tmp26_ = 0;
						GtkWidget* widget = NULL;
						BoxesProperty* _tmp27_ = NULL;
						GtkWidget* _tmp28_ = NULL;
						GtkWidget* _tmp29_ = NULL;
						GtkWidget* _tmp30_ = NULL;
						GtkWidget* _tmp31_ = NULL;
						GtkWidget* _tmp32_ = NULL;
						gint _tmp33_ = 0;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp16_ = property;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp17_ = boxes_property_get_description (_tmp16_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp18_ = _tmp17_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp19_ = (GtkLabel*) gtk_label_new (_tmp18_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						g_object_ref_sink (_tmp19_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						label_name = _tmp19_;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp20_ = label_name;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp21_ = gtk_widget_get_style_context ((GtkWidget*) _tmp20_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_style_context_add_class (_tmp21_, "boxes-property-name-label");
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp22_ = label_name;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_margin_left ((GtkWidget*) _tmp22_, 25);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp23_ = label_name;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_halign ((GtkWidget*) _tmp23_, GTK_ALIGN_START);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp24_ = label_name;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_hexpand ((GtkWidget*) _tmp24_, FALSE);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp25_ = label_name;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp26_ = current_row;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) _tmp25_, 0, _tmp26_, 1, 1);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp27_ = property;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp28_ = boxes_property_get_widget (_tmp27_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp29_ = _tmp28_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp30_ = _g_object_ref0 (_tmp29_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						widget = _tmp30_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp31_ = widget;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_hexpand (_tmp31_, TRUE);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp32_ = widget;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp33_ = current_row;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_grid_attach ((GtkGrid*) self, _tmp32_, 1, _tmp33_, 1, 1);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_object_unref0 (widget);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_object_unref0 (label_name);
#line 1985 "properties.c"
					} else {
						GtkWidget* widget = NULL;
						BoxesProperty* _tmp34_ = NULL;
						GtkWidget* _tmp35_ = NULL;
						GtkWidget* _tmp36_ = NULL;
						GtkWidget* _tmp37_ = NULL;
						GtkWidget* _tmp38_ = NULL;
						GtkWidget* _tmp39_ = NULL;
						GtkWidget* _tmp40_ = NULL;
						gint _tmp41_ = 0;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp34_ = property;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp35_ = boxes_property_get_widget (_tmp34_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp36_ = _tmp35_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp37_ = _g_object_ref0 (_tmp36_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						widget = _tmp37_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp38_ = widget;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_hexpand (_tmp38_, TRUE);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp39_ = widget;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_margin_left (_tmp39_, 25);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp40_ = widget;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp41_ = current_row;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_grid_attach ((GtkGrid*) self, _tmp40_, 0, _tmp41_, 2, 1);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_object_unref0 (widget);
#line 2022 "properties.c"
					}
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp42_ = property;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp43_ = boxes_property_get_extra_widget (_tmp42_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp44_ = _tmp43_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp45_ = _g_object_ref0 (_tmp44_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					widget = _tmp45_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp46_ = widget;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					if (_tmp46_ != NULL) {
#line 2038 "properties.c"
						gint _tmp47_ = 0;
						GtkWidget* _tmp48_ = NULL;
						GtkWidget* _tmp49_ = NULL;
						GtkWidget* _tmp50_ = NULL;
						gint _tmp51_ = 0;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp47_ = current_row;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						current_row = _tmp47_ + 1;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp48_ = widget;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_margin_left (_tmp48_, 25);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp49_ = widget;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_hexpand (_tmp49_, TRUE);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp50_ = widget;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp51_ = current_row;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_grid_attach ((GtkGrid*) self, _tmp50_, 0, _tmp51_, 2, 1);
#line 2062 "properties.c"
					}
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp52_ = property;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					g_signal_connect_object (_tmp52_, "refresh-properties", (GCallback) ______lambda54__boxes_property_refresh_properties, self, 0);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp53_ = current_row;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					current_row = _tmp53_ + 1;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_g_object_unref0 (widget);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_g_object_unref0 (property);
#line 2076 "properties.c"
				}
			}
		}
	}
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return self;
#line 2085 "properties.c"
}


static BoxesPropertiesPageWidget* boxes_properties_page_widget_new (BoxesPropertiesPage page, BoxesMachine* machine) {
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return boxes_properties_page_widget_construct (BOXES_PROPERTIES_TYPE_PAGE_WIDGET, page, machine);
#line 2092 "properties.c"
}


static gboolean boxes_properties_page_widget_flush_changes (BoxesPropertiesPageWidget* self) {
	gboolean result = FALSE;
	gboolean reboot_required = FALSE;
	GList* _tmp0_ = NULL;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	reboot_required = FALSE;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->properties;
#line 2106 "properties.c"
	{
		GList* property_collection = NULL;
		GList* property_it = NULL;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		property_collection = _tmp0_;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		for (property_it = property_collection; property_it != NULL; property_it = property_it->next) {
#line 2114 "properties.c"
			BoxesProperty* _tmp1_ = NULL;
			BoxesProperty* property = NULL;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp1_ = _g_object_ref0 ((BoxesProperty*) property_it->data);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			property = _tmp1_;
#line 2121 "properties.c"
			{
				BoxesProperty* _tmp2_ = NULL;
				gboolean _tmp3_ = FALSE;
				BoxesProperty* _tmp4_ = NULL;
				gboolean _tmp5_ = FALSE;
				gboolean _tmp6_ = FALSE;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp2_ = property;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				boxes_property_flush (_tmp2_);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp3_ = reboot_required;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp4_ = property;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp5_ = boxes_property_get_reboot_required (_tmp4_);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp6_ = _tmp5_;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				reboot_required = _tmp3_ | _tmp6_;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_object_unref0 (property);
#line 2144 "properties.c"
			}
		}
	}
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	result = reboot_required;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return result;
#line 2152 "properties.c"
}


static void boxes_properties_page_widget_class_init (BoxesPropertiesPageWidgetClass * klass) {
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_page_widget_parent_class = g_type_class_peek_parent (klass);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_type_class_add_private (klass, sizeof (BoxesPropertiesPageWidgetPrivate));
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_properties_page_widget_finalize;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_signal_new ("refresh_properties", BOXES_PROPERTIES_TYPE_PAGE_WIDGET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 2165 "properties.c"
}


static void boxes_properties_page_widget_instance_init (BoxesPropertiesPageWidget * self) {
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv = BOXES_PROPERTIES_PAGE_WIDGET_GET_PRIVATE (self);
#line 2172 "properties.c"
}


static void boxes_properties_page_widget_finalize (GObject* obj) {
	BoxesPropertiesPageWidget * self;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidget);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	__g_list_free__g_object_unref0_0 (self->priv->properties);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (boxes_properties_page_widget_parent_class)->finalize (obj);
#line 2184 "properties.c"
}


static GType boxes_properties_page_widget_get_type (void) {
	static volatile gsize boxes_properties_page_widget_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_page_widget_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesPropertiesPageWidgetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_properties_page_widget_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesPropertiesPageWidget), 0, (GInstanceInitFunc) boxes_properties_page_widget_instance_init, NULL };
		GType boxes_properties_page_widget_type_id;
		boxes_properties_page_widget_type_id = g_type_register_static (GTK_TYPE_GRID, "BoxesPropertiesPageWidget", &g_define_type_info, 0);
		g_once_init_leave (&boxes_properties_page_widget_type_id__volatile, boxes_properties_page_widget_type_id);
	}
	return boxes_properties_page_widget_type_id__volatile;
}


static void boxes_properties_class_init (BoxesPropertiesClass * klass) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_parent_class = g_type_class_peek_parent (klass);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_type_class_add_private (klass, sizeof (BoxesPropertiesPrivate));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_properties_get_property;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_properties_set_property;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_properties_finalize;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTIES_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTIES_PREVIOUS_UI_STATE, g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTIES_UI_STATE, g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2217 "properties.c"
}


static void boxes_properties_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	iface->get_actor = boxes_properties_real_get_actor;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	iface->get_previous_ui_state = boxes_properties_real_get_previous_ui_state;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	iface->set_previous_ui_state = boxes_properties_real_set_previous_ui_state;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	iface->get_ui_state = boxes_properties_real_get_ui_state;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	iface->set_ui_state = boxes_properties_real_set_ui_state;
#line 2234 "properties.c"
}


static void boxes_properties_instance_init (BoxesProperties * self) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv = BOXES_PROPERTIES_GET_PRIVATE (self);
#line 2241 "properties.c"
}


static void boxes_properties_finalize (GObject* obj) {
	BoxesProperties * self;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_PROPERTIES, BoxesProperties);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (boxes_properties_parent_class)->finalize (obj);
#line 2253 "properties.c"
}


GType boxes_properties_get_type (void) {
	static volatile gsize boxes_properties_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesPropertiesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_properties_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesProperties), 0, (GInstanceInitFunc) boxes_properties_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_properties_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_properties_type_id;
		boxes_properties_type_id = g_type_register_static (GTK_TYPE_NOTEBOOK, "BoxesProperties", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_properties_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_properties_type_id__volatile, boxes_properties_type_id);
	}
	return boxes_properties_type_id__volatile;
}


static void _vala_boxes_properties_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesProperties * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_PROPERTIES, BoxesProperties);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	switch (property_id) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_ACTOR:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PREVIOUS_UI_STATE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_UI_STATE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 2294 "properties.c"
		default:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 2300 "properties.c"
	}
}


static void _vala_boxes_properties_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesProperties * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_PROPERTIES, BoxesProperties);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	switch (property_id) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PREVIOUS_UI_STATE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_UI_STATE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 2322 "properties.c"
		default:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 2328 "properties.c"
	}
}



